@@ -3,12 +3,13 @@ Main interface for sagemaker-runtime service type definitions.
 
 Usage::
 
-    from mypy_boto3.sagemaker_runtime.type_defs import InvokeEndpointOutputTypeDef
+    ```python
+    from mypy_boto3_sagemaker_runtime.type_defs import InvokeEndpointOutputTypeDef
 
     data: InvokeEndpointOutputTypeDef = {...}
+    ```
 """
 import sys
-from typing import IO, Union
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -19,7 +20,7 @@ else:
 __all__ = ("InvokeEndpointOutputTypeDef",)
 
 _RequiredInvokeEndpointOutputTypeDef = TypedDict(
-    "_RequiredInvokeEndpointOutputTypeDef", {"Body": Union[bytes, IO]}
+    "_RequiredInvokeEndpointOutputTypeDef", {"Body": bytes}
 )
 _OptionalInvokeEndpointOutputTypeDef = TypedDict(
     "_OptionalInvokeEndpointOutputTypeDef",
